uniform sampler2D 		uColorMap;
uniform sampler2D 		uNormalMap;

varying vec3			vTSpaceEyeVector;
varying vec3			vTSpaceLight;
varying vec2			vTexCoord;

const float				kShininess = 10.0;
const float				kDiffuse = 0.8;
const float				kSpecular = 0.3;
const float				kAmbient = 0.05;


#define COLOR			1


void main()
{
	vec3 lightT = normalize(vTSpaceLight);
	vec3 eye = normalize(vTSpaceEyeVector);
	
	vec2 texCoord = vTexCoord;
	
	vec3 normalMap = texture2D(uNormalMap, texCoord).xyz - 0.5;
	normalMap = normalize(normalMap);
	
#if COLOR
	vec4 colorMap = texture2D(uColorMap, texCoord);
#else
	vec4 colorMap = vec4(1.0);
#endif
	
	float ambient = kAmbient;
	float diffuse = max(dot(lightT, normalMap), 0.0) * kDiffuse;
	float specular = pow(clamp(dot(reflect(-lightT, normalMap), eye), 0.0, 1.0), kShininess) * kSpecular;
	
	vec3 color = diffuse * colorMap.rgb + specular * vec3(1.0) + ambient * colorMap.rgb;

#if 0
	// Debug: output normal map
	color = normalMap / 2.0 + 0.5, 1.0;
#endif
	
	gl_FragColor = vec4(color, 1.0);
}
