#ifdef OO_TANGENT_ATTR
attribute vec3			tangent;
#else
/*	Oolite 1.72 still doesn't provide tangent attributes!
	Hard-coded value demonstrates the basic idea, but only works with surfaces
	oriented a certain way.
*/
const vec3				tangent = vec3(1.0, 0.0, 0.0);
#endif

varying vec3			vTSpaceEyeVector;
varying vec3			vTSpaceLight;
varying vec2			vTexCoord;


void main()
{
	// Build tangent basis
	vec3 normal = normalize(gl_NormalMatrix * gl_Normal);
	vec3 tangent = normalize(gl_NormalMatrix * tangent);
	vec3 binormal = cross(normal, tangent);
	
	vec3 eyeVector = -vec3(gl_ModelViewMatrix * gl_Vertex);
	
#ifdef OO_TEXTURE_UNIT_COUNT
	vec3 lightVector = gl_LightSource[0].position.xyz;
#else
	vec3 lightVector = vec3(15.0, 20.0, 30.0);
#endif
	
	lightVector += eyeVector;
	
	mat3 TBN = mat3(tangent, binormal, normal);
	
	vTSpaceLight = lightVector * TBN;
	vTSpaceEyeVector = eyeVector * TBN;
	
	vTexCoord = gl_MultiTexCoord0.st;
	gl_Position = ftransform();
}
